# Kubernetes Lite

Kubernetes Lite is a "liteweight" wrapper around various golang Kubernetes libraries using [gopy](https://github.com/go-python/gopy). It brings the benefits of go's resource efficiency plus the feature set of packages like [client-go](k8s.io/client-go) and the [controller-runtime](https://pkg.go.dev/sigs.k8s.io/controller-runtime) to Python.

For API details, please refer to the [API References](API References.md).

